@@ -6,14 +6,14 @@ use Moo;
 use AE;
 use AnyEvent;
 use AnyEvent::Handle;
-use AnyEvent::Socket qw( tcp_connect );
+use AnyEvent::Socket ();
 use Protocol::WebSocket::Request;
 use Protocol::WebSocket::Handshake::Client;
 use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.36'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 
 has timeout => (
@@ -63,6 +63,11 @@ has http_headers => (
 );
 
 
+has max_payload_size => (
+  is => 'ro',
+);
+
+
 sub connect
 {
   my($self, $uri) = @_;
@@ -82,7 +87,7 @@ sub connect
     return $done;
   }
     
-  tcp_connect $uri->host, $uri->port, sub {
+  AnyEvent::Socket::tcp_connect $uri->host, $uri->port, sub {
     my $fh = shift;
     unless($fh)
     {
@@ -152,9 +157,10 @@ sub connect
         undef $handshake;
         $done->send(
           AnyEvent::WebSocket::Connection->new(
-                  handle      => $hdl,
-                  masked      => 1,
-            maybe subprotocol => $sb,
+                  handle           => $hdl,
+                  masked           => 1,
+            maybe subprotocol      => $sb,
+            maybe max_payload_size => $self->max_payload_size,
           )
         );
         undef $hdl;
@@ -179,7 +185,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -297,6 +303,11 @@ Will generate:
 
 Although, the order cannot be guaranteed when using the hash style.
 
+=head2 max_payload_size
+
+The maximum payload size for received frames.  Currently defaults to whatever
+L<Protocol::WebSocket> defaults to.
+
 =head1 METHODS
 
 =head2 connect
