@@ -8,10 +8,11 @@ use Scalar::Util ();
 use Encode ();
 use AE;
 use AnyEvent::WebSocket::Message;
+use PerlX::Maybe qw( maybe provided );
 use Carp ();
 
 # ABSTRACT: WebSocket connection for AnyEvent
-our $VERSION = '0.36'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 
 has handle => (
@@ -30,7 +31,12 @@ has subprotocol => (
   is => 'ro',
 );
 
-foreach my $type (qw( each_message next_message finish ))
+
+has max_payload_size => (
+  is => 'ro',
+);
+
+foreach my $type (qw( each_message next_message finish parse_error ))
 {
   has "_${type}_cb" => (
     is       => 'ro',
@@ -79,7 +85,7 @@ sub BUILD
   $self->handle->on_error($finish);
   $self->handle->on_eof($finish);
 
-  my $frame = Protocol::WebSocket::Frame->new;
+  my $frame = Protocol::WebSocket::Frame->new( maybe max_payload_size => $self->max_payload_size );
 
   my $read_cb = sub {
     my ($handle) = @_;
@@ -103,12 +109,13 @@ sub BUILD
         {
           push(@temp_messages, $message);
         }
-      };
+      }
       1; # succeed to parse.
     };
     if(!$success)
     {
       $self->_force_shutdown();
+      $_->($self, $@) for @{ $self->_parse_error_cb };
     }
   };
 
@@ -191,12 +198,12 @@ sub send
   
   if(ref $message)
   {
-    $frame = Protocol::WebSocket::Frame->new(buffer => $message->body, masked => $self->masked);
+    $frame = Protocol::WebSocket::Frame->new(buffer => $message->body, masked => $self->masked, max_payload_size => 0);
     $frame->opcode($message->opcode);
   }
   else
   {
-    $frame = Protocol::WebSocket::Frame->new(buffer => $message, masked => $self->masked);
+    $frame = Protocol::WebSocket::Frame->new(buffer => $message, masked => $self->masked, max_payload_size => 0);
   }
   $self->handle->push_write($frame->to_bytes);
   $self;
@@ -219,6 +226,10 @@ sub on
   {
     push @{ $self->_finish_cb }, $cb;
   }
+  elsif($event eq 'parse_error')
+  {
+    push @{ $self->_parse_error_cb }, $cb;
+  }
   else
   {
     Carp::croak "unrecongized event: $event";
@@ -258,7 +269,7 @@ AnyEvent::WebSocket::Connection - WebSocket connection for AnyEvent
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -321,6 +332,11 @@ If set to true, it masks outgoing frames. The default is false.
 The subprotocol returned by the server.  If no subprotocol was requested, it
 may be C<undef>.
 
+=head2 max_payload_size
+
+The maximum payload size for received frames.  Currently defaults to whatever
+L<Protocol::WebSocket> defaults to.
+
 =head1 METHODS
 
 =head2 send
@@ -354,6 +370,15 @@ Called each time a message is received from the WebSocket.
 
 Called only for the next message received from the WebSocket.
 
+=head3 parse_error
+
+ $cb->($connection, $text_error_message)
+
+Called if there is an error parsing a message sent from the remote end.
+After this callback is called, the connection will be closed.
+Among other possible errors, this event will trigger if a frame has a
+payload which is larger that C<max_payload_size>.
+
 =head3 finish
 
  $cb->($connection)
